<?php
// $Id: fetchgals_settings.inc,v 1.1.2.1 2008/02/25 09:50:38 pobster Exp $

/**
 * Implementation of hook_settings
 */
function fetchgals_settings() {
  $form['cron_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Cron Settings:'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['cron_settings']['fetchgals_cron'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use cron to manage fetchgals?'),
    '#default_value' => variable_get('fetchgals_cron', 0),
    '#description' => t('Assuming you have your cron set up properly, checking this will automate fetchgals'),
  );
  foreach (range('0', '23') as $i) {
    $time[$i] = date('g:00a', mktime($i));
  }
  $form['cron_settings']['fetchgals_timecron'] = array(
    '#type' => 'select',
    '#title' => t('Time of day for cron'),
    '#default_value' => variable_get('fetchgals_timecron', 3),
    '#options' => $time,
    '#description' => t("Depending on what you've set below, this setting makes sure the cronjobs only execute at sensible times of the day when the extra load on your server won't affect anyone"),
  );
  $form['cron_settings']['fetchgals_fetch'] = array(
    '#type' => 'select',
    '#title' => t('How often to fetch'),
    '#default_value' => variable_get('fetchgals_fetch', 86400),
    '#options' => array(NULL => 'Never', 86400 => 'Daily', 172800 => 'Every other day', 604800 => 'Weekly'),
    '#description' => t('Runs both -find_galleries and -create_html (including all your default settings from below) during your scheduled cron job to create a completely new set of galleries'),
  );
  $form['cron_settings']['fetchgals_clean'] = array(
    '#type' => 'select',
    '#title' => t('How often to empty folder'),
    '#default_value' => variable_get('fetchgals_clean', 604800),
    '#options' => array(NULL => 'Never', 86400 => 'Daily', 172800 => 'Every other day', 604800 => 'Weekly'),
    '#description' => t("Completely removes all html files in folder '%folder' during your scheduled cron job", array('%folder' => variable_get('fetchgals_html_dir', './porn_html'))),
  );
  $form['fetchgals_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Fetchgals Settings:'),
    '#description' => t("<h1><em>Only change these settings if you absolutely know what you're doing!</em></h1>
      <br>Note: Any directory prefixed by '<strong>./</strong>' will appear in your <em>%dir</em> directory, other than
      that please use FULL paths eg. <em>/tmp/porn_pics</em>",
      array('%dir' => drupal_get_path('module', 'fetchgals') .'/fetchgals')
    ),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['fetchgals_settings']['fetchgals_tgp_file'] = array(
    '#type' => 'textfield',
    '#title' => t('TGP File'),
    '#default_value' => variable_get('fetchgals_tgp_file', './tgps'),
    '#size' => 50,
    '#description' => t("The file that contains URLs of TGPs, one per line; lines starting with
      # are comments and are ignored. Defaults to <em>./tgps</em>. This option is
      only needed by the <strong>-find_galleries</strong> action.
      <p>Two TGP files are distributed with <strong>fetchgals</strong>. Others can be
      generated with the program <em>findtgps(1)</em>.</p>"
    ),
  );
  $form['fetchgals_settings']['fetchgals_extensive_search'] = array(
    '#type' => 'checkbox',
    '#title' => t('Extensive Search'),
    '#default_value' => variable_get('fetchgals_extensive_search', 0),
    '#description' => t("This option affects the operation of the <strong>-find_galleries</strong> action.
      Without it, only links from TGPs are investigated that expose the true
      location of the gallery in the URL. If <strong>-extensive_search</strong> is
      switched on, other links are followed as well; they have to be ``tried
      out'' to find the gallery's location, and often this has to be repeated
      several times until the gallery's URL is found. The <strong>-find_galleries</strong>
      action is much slower when <strong>-extensive_search</strong> is switched on, and
      for most users it is probably not worth it."
    ),
  );
  $form['fetchgals_settings']['fetchgals_attempts_per_link'] = array(
    '#type' => 'textfield',
    '#title' => t('Attempts Per Link'),
    '#default_value' => variable_get('fetchgals_attempts_per_link', 5),
    '#size' => 5,
    '#description' => t("The number of times a link to a gallery is followed (default: 5). Many
      TGPs use CGI scripts as links to the galleries, and these scripts
      frequently redirect to another TGP rather than to the gallery. If this
      happens to us, we try the link again, until we find a <em>bona fide</em>
      gallery or we exceed num attempts. This option only has an effect if
      <strong>-extensive_search</strong> is being used."
    ),
  );
  $form['fetchgals_settings']['fetchgals_sleep_time'] = array(
    '#type' => 'textfield',
    '#title' => t('Sleep Time'),
    '#default_value' => variable_get('fetchgals_sleep_time', 7),
    '#size' => 5,
    '#description' => t("The average time (in seconds) between accesses to the same TGP
      (default is 7). This is an average; the actual waiting time is
      randomized. The purpose is to avoid our bot being detected. We cycle
      through the TGPs so that we don't have to sleep often.
      <p>This option only affects the <strong>-find_galleries</strong> action if the
      <strong>-extensive_search</strong> option is switched on. Without
      <strong>-extensive_search</strong>, we never have to sleep. If you get many ``bot
      detected'' messages during the <strong>-find_galleries</strong> action, you need to
      increase the sleep time.</p>"
    ),
  );
  $form['fetchgals_settings']['fetchgals_gallery_file'] = array(
    '#type' => 'textfield',
    '#title' => t('Gallery File'),
    '#default_value' => variable_get('fetchgals_gallery_file', './galleries'),
    '#size' => 50,
    '#description' => t("The file that contains URLs of galleries and preview thumbnails, one
      gallery and one thumbnail per line, separated by a space. Defaults to
      <em>./galleries</em>. Before the <strong>-find_galleries</strong> action starts to collect
      galleries, it reads this file so that it won't have to test a
      previously seen gallery. It then appends newly found galleries. The
      file is read by the <strong>-create_html</strong> and <strong>-download_pics</strong> actions.
      <p>If the file doesn't exist, then it will be created.</p>"
    ),
  );
  $form['fetchgals_settings']['fetchgals_use_cookies'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Cookies'),
    '#default_value' => variable_get('fetchgals_use_cookies', 0),
    '#description' => t("With this option, <strong>fetchgals</strong> will save the cookies it receives
      and return them to TGPs and galleries. By default, cookies are not
      used."
    ),
  );
  $form['fetchgals_settings']['fetchgals_pics_dir'] = array(
    '#type' => 'textfield',
    '#title' => t('Pictures Directory'),
    '#default_value' => variable_get('fetchgals_pics_dir', './porn_pics'),
    '#size' => 50,
    '#description' => t("The directory where the <strong>-download_pics</strong> action stores the downloaded
      images. Defaults to <em>./porn_pics</em>. The directory will be created if it
      doesn't exist. The pictures receive names indicating their origin and
      are stored in subdirectories a-z depending on the first letter of
      their name."
    ),
  );
  $form['fetchgals_settings']['fetchgals_processed_downloads_file'] = array(
    '#type' => 'textfield',
    '#title' => t('Processed Downloads File'),
    '#default_value' => variable_get('fetchgals_processed_downloads_file', './gals_downloaded'),
    '#size' => 50,
    '#description' => t("The file where the URLs of downloaded galleries are recorded. Defaults
      to <em>./gals_downloaded</em>. This is only used by the <strong>-download_pics</strong>
      action, to avoid repeated downloads of the same gallery. The file will
      be created if it doesn't exist."
    ),
  );
  $form['fetchgals_settings']['fetchgals_types'] = array(
    '#type' => 'textfield',
    '#title' => t('Types'),
    '#default_value' => variable_get('fetchgals_types', 'jpg|jpeg|gif|png|mpg|mpeg|avi|asf|mov|wmv'),
    '#size' => 100,
    '#description' => t("A regular expression matching the extensions of files you want to
      download. Defaults to jpg|jpeg|gif|png|mpg|mpeg|avi|asf|mov|wmv.
      The match is case-insensitive, so you don't need to list the
      upper-case variants. Note that if you want to download videos, you
      need to increase <strong>-max_img_size</strong>."
    ),
  );
  $form['fetchgals_settings']['fetchgals_min_img_size'] = array(
    '#type' => 'textfield',
    '#title' => t('Minimum Image Size'),
    '#default_value' => variable_get('fetchgals_min_img_size', 15000),
    '#size' => 10,
    '#description' => t("The minimum size (in bytes) of image files to download (default:
      15000). This is only used by the <strong>-download_pics</strong> action; files
      smaller than this threshold are taken to be thumbnails or advertising
      banners and not downloaded."
    ),
  );
  $form['fetchgals_settings']['fetchgals_max_img_size'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum Image Size'),
    '#default_value' => variable_get('fetchgals_max_img_size', 250000),
    '#size' => 10,
    '#description' => t("The maximum size (in bytes) of image files to download (default:
      250000). This is only used by the <strong>-download_pics</strong> action; files
      larger than this threshold are not downloaded. If you are interested
      in movies, you want to set this to 10000000."
    ),

  );
  $form['fetchgals_settings']['fetchgals_max_disk_usage'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum Disk Usage'),
    '#default_value' => variable_get('fetchgals_max_disk_usage', 95),
    '#size' => 4,
    '#description' => t("The image download is stopped if the disk usage exceeds <em>num</em>%
      (default: 95). This percentage is based on the total disk space
      available to non-superusers. Your system may reserve some additional
      disk space for the super user."
    ),
  );
  $form['fetchgals_settings']['fetchgals_pic_file_template'] = array(
    '#type' => 'textfield',
    '#title' => t('Picture File Template'),
    '#default_value' => variable_get('fetchgals_pic_file_template', '%i/%h-%p-%n%e'),
    '#size' => 40,
    '#description' => t("The template to be used for the filenames of the downloaded images. This is a string containing the following special place holdersq:<p>
      <dl><dt><strong>%h</strong></dt><dd>The host name of the gallery, with leading ``www.'' removed.</dd>
      <dt><strong>%i</strong></dt><dd>The first letter of the host name, or ``z'' if that is a digit. </dd>
      <dt><strong>%p</strong></dt><dd>The path of the gallery's URL, with all slashes replaced by hyphens.</dd>
      <dt><strong>%d</strong></dt><dd>The current date.</dd>
      <dt><strong>%t</strong></dt><dd>The current time.</dd>
      <dt><strong>%n</strong></dt><dd>The number of the image within the gallery.</dd>
      <dt><strong>%c</strong></dt><dd>The filetype: either ``video'' or ``image''. Note that if you want
      <strong>fetchgals</strong> to download videos, you need to increase the default
      maximal file size with <strong>-max_img_size</strong>.</dd>
      <dt><strong>%e</strong></dt><dd>The filename extension giving the file's type. Starts with a period.</dd>
      <dt><strong>%%</strong></dt><dd>A literal %-sign.</dd></dl></p>
      <p>The default template is %i/%h-%p-%n%e. Every template should contain %h, %p and %n, or else some images run the risk of being overwritten.</p>"
    ),
  );
  $form['fetchgals_settings']['fetchgals_num_download_processes'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of Download Processes'),
    '#default_value' => variable_get('fetchgals_num_download_processes', 8),
    '#size' => 4,
    '#description' => t("The number of parallel processes used to download pictures (default:
      8). This only affects the <strong>-download_pics</strong> action.
      <p>We use parallel processes because today's cable and DSL internet
      connections allow much faster downloads than a single porn host can
      provide. Experiment with this number until your download speeds
      approach the bandwidth of your internet connection.</p>"
    ),
  );
  $form['fetchgals_settings']['fetchgals_html_dir'] = array(
    '#type' => 'textfield',
    '#title' => t('HTML Directory'),
    '#default_value' => variable_get('fetchgals_html_dir', './porn_html'),
    '#size' => 50,
    '#description' => t("The directory where the <strong>-create_html</strong> action creates the HTML files.
      Defaults to <em>./porn_html</em>. The directory will be created if it
      doesn't exist. The file <em>index.html</em> in that directory links to the
      other created HTML files."
    ),
  );
  $form['fetchgals_settings']['fetchgals_thumbs_per_row'] = array(
    '#type' => 'textfield',
    '#title' => t('Thumbs Per Row'),
    '#default_value' => variable_get('fetchgals_thumbs_per_row', 6),
    '#size' => 4,
    '#description' => t("The number of thumbnail pictures that will be put in one horizontal
      row of the resulting HTML file. Defaults to 6. Only used by the
      <strong>-create_html</strong> action."
    ),
  );
  $form['fetchgals_settings']['fetchgals_rows_per_file'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of Rows Per File'),
    '#default_value' => variable_get('fetchgals_rows_per_file', 10),
    '#size' => 4,
    '#description' => t("The number of rows that we be put in each of the resulting HTML files.
      Defaults to 10. Only used by the <strong>-create_html</strong> action."
    ),
  );
  $form['fetchgals_settings']['fetchgals_processed_html_file'] = array(
    '#type' => 'textfield',
    '#title' => t('Processed HTML File'),
    '#default_value' => variable_get('fetchgals_processed_html_file', './gals_processed_html'),
    '#size' => 50,
    '#description' => t("The file where the URLs of galleries are recorded that have been
      processed with the <strong>-create_html</strong> action. Defaults to
      <em>./gals_processed_html</em>. This is only used by the <strong>-download_pics</strong>
      action, to avoid repeated downloads of the same gallery. The file will
      be created if it doesn't exist."
    ),
  );
  $form['findtgps_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('FindTGPS Settings:'),
    '#description' => t("<h1><em>Only change these settings if you absolutely know what you're doing!</em></h1>"),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['findtgps_settings']['findtgps_in'] = array(
    '#type' => 'textfield',
    '#title' => t("'In' File"),
    '#default_value' => variable_get('findtgps_in', './tgps'),
    '#size' => 50,
    '#description' => t("<p>Given a file <em>infile</em> containing URLs of TGPs, one per line,
      <strong>findtgps</strong> will follow links from those TGPs in order to find others.
      All found TGPs will be stored in <em>outfile</em>. Both <em>infile</em> and
      <em>outfile</em> have to be specified; they may be identical, but <em>outfile</em>
      will be overwritten.</p>
      <p>Along with the URL, <strong>findtgps</strong> will record three numbers in <em>outfile</em>:
      the number of gallery links that expose the URL, the number of
      potential gallery links that go through a CGI script, and the number of direct links to galleries. The links through CGI scripts are the most inconvenient to deal with.</p>
      <p>The purpose of <strong>findtgps</strong> is to create an input file for <em>fetchgals(1)</em>.</p>"
    ),
  );
  $form['findtgps_settings']['findtgps_out'] = array(
    '#type' => 'textfield',
    '#title' => t("'Out' File"),
    '#default_value' => variable_get('findtgps_out', './tgps'),
    '#size' => 50,
    '#description' => t("See above."),
  );
  $form['findtgps_settings']['findtgps_known_tgps'] = array(
    '#type' => 'textfield',
    '#title' => t('Known TGPS'),
    '#default_value' => variable_get('findtgps_known_tgps', './tgps'),
    '#size' => 50,
    '#description' => t("This is a file of known TGPS, one per line, which don't need to be checked again."),
  );
  $form['findtgps_settings']['findtgps_link_threshold'] = array(
    '#type' => 'textfield',
    '#title' => t('Link Threshold'),
    '#default_value' => variable_get('findtgps_link_threshold', 30),
    '#size' => 4,
    '#description' => t("The number of external links a page needs to contain before we classify it as a TGP. Default is 30."),
  );
  $form['findtgps_settings']['findtgps_fraction_followed'] = array(
    '#type' => 'textfield',
    '#title' => t('Fraction Followed'),
    '#default_value' => variable_get('findtgps_fraction_followed', 6),
    '#size' => 4,
    '#description' => t("If we have located a TGP, we will follow every <em>num</em>'th link to find
      new TGPs. Default is 6. One might be inclined to use
      <strong>-fraction_followed</strong> 1, but this is not advisable since TGPs usually
      link (through a CGI script) to only a small number of other TGPs."
    ),
  );
  $form['findtgps_settings']['findtgps_threads'] = array(
    '#type' => 'textfield',
    '#title' => t('Threads'),
    '#default_value' => variable_get('findtgps_threads', 8),
    '#size' => 4,
    '#description' => t("The number of parallel threads used for the task. Defaults to 8."),
  );
  return system_settings_form($form);
} // fetchgals_settings
